==> qore-1.19.1.tar.bz2: qore-1.19.1/docs/modules/DataProvider/html/index.js <==
var index =
[
    [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
      [ "Data Provider Modules", "index.html#dataprovider_modules", [
        [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
        [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
      ] ]
    ] ],
    [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
    [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
    [ "Release Notes", "index.html#dataprovider_relnotes", [
      [ "DataProvider v2.7.4", "index.html#dataprovider_v2_7_4", null ],
      [ "DataProvider v2.7.3", "index.html#dataprovider_v2_7_3", null ],
      [ "DataProvider v2.7.2", "index.html#dataprovider_v2_7_2", null ],
      [ "DataProvider v2.7.1", "index.html#dataprovider_v2_7_1", null ],
      [ "DataProvider v2.7", "index.html#dataprovider_v2_7", null ],
      [ "DataProvider v2.6", "index.html#dataprovider_v2_6", null ],
      [ "DataProvider v2.5", "index.html#dataprovider_v2_5", null ],
      [ "DataProvider v2.4", "index.html#dataprovider_v2_4", null ],
      [ "DataProvider v2.3", "index.html#dataprovider_v2_3", null ],
      [ "DataProvider v2.2.1", "index.html#dataprovider_v2_2_1", null ],
      [ "DataProvider v2.2", "index.html#dataprovider_v2_2", null ],
      [ "DataProvider v2.1.2", "index.html#dataprovider_v2_1_2", null ],
      [ "DataProvider v2.1.1", "index.html#dataprovider_v2_1_1", null ],
      [ "DataProvider v2.1", "index.html#dataprovider_v2_1", null ],
      [ "DataProvider v2.0", "index.html#dataprovider_v2_0", null ],
      [ "DataProvider v1.3", "index.html#dataprovider_v1_2_3", null ],
      [ "DataProvider v1.2.2", "index.html#dataprovider_v1_2_2", null ],
      [ "DataProvider v1.2.1", "index.html#dataprovider_v1_2_1", null ],
      [ "DataProvider v1.2", "index.html#dataprovider_v1_2", null ],
      [ "DataProvider v1.1", "index.html#dataprovider_v1_1", null ],
      [ "DataProvider v1.0.6", "index.html#dataprovider_v1_0_6", null ],
      [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
      [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
      [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
      [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
      [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
      [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
    ] ]
];

==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/DataProvider/html/index.js <==
var index =
[
    [ "Introduction to the DataProvider Module", "index.html#dataproviderintro", [
      [ "Data Provider Modules", "index.html#dataprovider_modules", [
        [ "Data Provider Dynamic Discovery", "index.html#dataprovider_dynamic_discovery", null ],
        [ "Data Provider Type Dynamic Discovery", "index.html#dataprovider_type_dynamic_discovery", null ]
      ] ]
    ] ],
    [ "Data Provider Pipelines", "index.html#dataprovider_pipelines", null ],
    [ "Data Provider Pipeline Bulk Processing", "index.html#dataprovider_pipeline_bulk_processing", null ],
    [ "Release Notes", "index.html#dataprovider_relnotes", [
      [ "DataProvider v3.0", "index.html#dataprovider_v3_0", null ],
      [ "DataProvider v2.7.5", "index.html#dataprovider_v2_7_5", null ],
      [ "DataProvider v2.7.4", "index.html#dataprovider_v2_7_4", null ],
      [ "DataProvider v2.7.3", "index.html#dataprovider_v2_7_3", null ],
      [ "DataProvider v2.7.2", "index.html#dataprovider_v2_7_2", null ],
      [ "DataProvider v2.7.1", "index.html#dataprovider_v2_7_1", null ],
      [ "DataProvider v2.7", "index.html#dataprovider_v2_7", null ],
      [ "DataProvider v2.6", "index.html#dataprovider_v2_6", null ],
      [ "DataProvider v2.5", "index.html#dataprovider_v2_5", null ],
      [ "DataProvider v2.4", "index.html#dataprovider_v2_4", null ],
      [ "DataProvider v2.3", "index.html#dataprovider_v2_3", null ],
      [ "DataProvider v2.2.1", "index.html#dataprovider_v2_2_1", null ],
      [ "DataProvider v2.2", "index.html#dataprovider_v2_2", null ],
      [ "DataProvider v2.1.2", "index.html#dataprovider_v2_1_2", null ],
      [ "DataProvider v2.1.1", "index.html#dataprovider_v2_1_1", null ],
      [ "DataProvider v2.1", "index.html#dataprovider_v2_1", null ],
      [ "DataProvider v2.0", "index.html#dataprovider_v2_0", null ],
      [ "DataProvider v1.3", "index.html#dataprovider_v1_2_3", null ],
      [ "DataProvider v1.2.2", "index.html#dataprovider_v1_2_2", null ],
      [ "DataProvider v1.2.1", "index.html#dataprovider_v1_2_1", null ],
      [ "DataProvider v1.2", "index.html#dataprovider_v1_2", null ],
      [ "DataProvider v1.1", "index.html#dataprovider_v1_1", null ],
      [ "DataProvider v1.0.6", "index.html#dataprovider_v1_0_6", null ],
      [ "DataProvider v1.0.5", "index.html#dataprovider_v1_0_5", null ],
      [ "DataProvider v1.0.4", "index.html#dataprovider_v1_0_4", null ],
      [ "DataProvider v1.0.3", "index.html#dataprovider_v1_0_3", null ],
      [ "DataProvider v1.0.2", "index.html#dataprovider_v1_0_2", null ],
      [ "DataProvider v1.0.1", "index.html#dataprovider_v1_0_1", null ],
      [ "DataProvider v1.0", "index.html#dataprovider_v1_0", null ]
    ] ]
];
